import random as r

def mock(f=0, t=10000, decimal=2, neg=False):
    if f is None:
        f = 0
    if t is None:
        t = f+10000
    if neg == True:
        return round(r.uniform(f,t), decimal) * -1

    return round(r.uniform(f,t), decimal)


import random as r
from . import char
from . import date
from . import num
from . import price
from . import word

def mock(schema_json=None, count=10):
    result = []
    for i in range(count):
        data = {}
        for key, value in schema_json.items():
            if type(value) is dict:
                for child_key, child_value in value.items():
                    data[key] = mock(schema_json=value, count=1)[0]
            elif type(value) is list:
                if type(value[0]) is dict:
                    data[key] = mock(schema_json=value[0], count=count)
                else:
                    objs = mock(schema_json={ key : value[0] }, count=count)
                    data[key] = []
                    for obj in objs:
                        data[key].append(obj[key])
            elif value == "char":
                data[key] = char.mock()
            elif value == "date":
                data[key] = str(date.mock())
            elif value == "num":
                data[key] = num.mock()
            elif value == "price":
                data[key] = price.mock()
            else:
                normalize_key = key.replace("_","").lower()
                if "username" in normalize_key:
                    data[key] = word.mock(no_of_word=1)
                elif "name" in normalize_key:
                    data[key] = word.mock(no_of_word=r.choice([2,3]),upper_first_all=True)
                elif "gender" in normalize_key:
                    data[key] = word.mock_gender(upper_first=True)
                elif "phone" in normalize_key:
                    data[key] = word.mock_phone()
                elif "mail" in normalize_key:
                    data[key] = word.mock_email()
                elif "ipaddr" in normalize_key:
                    data[key] = word.mock_ip_address()
                elif normalize_key in ["tags","tag"]:
                    data[key] = word.mock_tag()
                else:
                    data[key] = word.mock(upper_first=True)
        
        result.append(data)

    return result


import random as r
from datetime import datetime, timedelta

def mock(f=datetime(1900,1,1), t=datetime.today()):
    if f is None:
        f = datetime(1900,1,1)
    if t is None:
        t = datetime.today()

    diff = abs(t-f).days + 1
        
    return f + timedelta(days=int(r.uniform(0,diff)))


from setuptools import setup

setup(
     name='pymocko',
     version='0.1.4',
     author='datnguye',
     author_email='datnguyen.it09@gmail.com',
     packages=['pymocko'],
     url='https://github.com/datnguye/pymocko',
     license='MIT',
     description='A package to generate mock data',
     long_description_content_type="text/markdown",
     long_description=open('README.md').read(),
     install_requires=[],
     python_requires='>=3.7.5'
)